@@ -87,6 +87,7 @@ def steinalp(f,numfac):
         # just array?
         return fsep
 
+
 def tsfill(valin,dtin,dtout):
     ''' purpose: regrid timeseries... fill missing timesteps in a timeseries with nan values, or leave out unwanted timesteps
     valin: time series values
@@ -94,7 +95,7 @@ def tsfill(valin,dtin,dtout):
     dtout: desired output timesteps
     '''
 
-    valout = zeros(len(dtout))*nan
+    valout = zeros([len(dtout)]+list(array(valin).shape[1:]))*nan
     lendtin = len(dtin)
     idtin = 0
     for idt,edt in enumerate(dtout):
@@ -105,6 +106,7 @@ def tsfill(valin,dtin,dtout):
             valout[idt] = valin[idtin]
     return valout
 
+
 def mergedata(x):
     x1 = x[0]
     x2 = x[1]
